==> benno-web-2.0.1-4.tgz: srv/benno/bennoweb/htdocs/tools/benno-functions.js <==

/* Sortierung der Nachrichten */
$('#select_nachricht').change(function(){
    document.forms.frm_select_nachricht.submit();
});

/* Anzahl der anzuzeigenden Ergebnisse */
$('#select_number').change(function(){
    document.forms.frm_select_number.submit();
});

/* Funktionen fuer die einfache Suche */
$('#submit_search_norm').click(function(){
    document.forms.frm_search_norm.submit();
});
var reset_search_normf = function(){
    $('#frm_search_norm').find(':input').each(function() {
        switch(this.type) {
            case 'text':
                $(this).val('');
                break;
            case 'select-multiple':
            case 'select-one':
                $(this).val('alle');
                break;
        }
    });
}
$('#reset_search_norm').click(function(){reset_search_normf()});

/* Funktionen fuer die erweiterte Suche */
$('#submit_search_ext').click(function(){
    document.forms.frm_search_ext.submit();
});
//$('#store_search_ext').click(function(){
//    $('#frm_search_ext_CA').val('storeQuery');
//    document.forms.frm_search_ext.submit();
//});
var reset_search_extf = function(){
  $('#frm_search_ext').find(':input').each(function() {
    switch(this.type) {
        case 'password':
        case 'select-multiple':
        case 'select-one':
        case 'text':
        case 'textarea':
            if (this.id == 'start-date') {
                $('#start-date').val('');
                break;
            }
            if (this.id == 'end-date') {
                $('#end-date').val('');
                break;
            }
            $(this).val('');
        break;
        case 'checkbox':
        case 'radio':
        this.checked = false;
    }
  });
}
$('#reset_search_ext').click(function(){reset_search_extf()});
$('#absender').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#betreff').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#empfaenger').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#volltext').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});


// datePicker localization
$.dpText = {
    TEXT_PREV_YEAR      :   'Letztes Jahr',
    TEXT_PREV_MONTH     :   'Vorheriger Monat',
    TEXT_NEXT_YEAR      :   'Nächstes Jahr',
    TEXT_NEXT_MONTH     :   'Nächster Monat',
    TEXT_CLOSE          :   'Schließen',
    TEXT_CHOOSE_DATE    :   'Datum auswählen',
    HEADER_FORMAT       :   'MMMM JJJJ'
};

==> benno-web-2.1.3.tgz: srv/benno/bennoweb/htdocs/tools/benno-functions.js <==

/* Sortierung der Nachrichten */
$('#select_nachricht').change(function(){
    document.forms.frm_select_nachricht.submit();
});

/* Anzahl der anzuzeigenden Ergebnisse */
$('#select_number').change(function(){
    document.forms.frm_select_number.submit();
});

/* Funktionen fuer die einfache Suche */
$('#submit_search_norm').click(function(){
    document.forms.frm_search_norm.submit();
});
var reset_search_normf = function(){
    $('#frm_search_norm').find(':input').each(function() {
        switch(this.type) {
            case 'text':
                $(this).val('');
                break;
            case 'select-multiple':
            case 'select-one':
                $(this).val('alle');
                break;
        }
    });
}
$('#reset_search_norm').click(function(){reset_search_normf()});

/* Funktionen fuer die erweiterte Suche */
$('#submit_search_ext').click(function(){
    document.forms.frm_search_ext.submit();
});
//$('#store_search_ext').click(function(){
//    $('#frm_search_ext_CA').val('storeQuery');
//    document.forms.frm_search_ext.submit();
//});
var reset_search_extf = function(){
  $('#frm_search_ext').find(':input').each(function() {
    switch(this.type) {
        case 'password':
        case 'select-multiple':
        case 'select-one':
        case 'text':
        case 'textarea':
            if (this.id == 'start-date') {
                $('#start-date').val('');
                break;
            }
            if (this.id == 'end-date') {
                $('#end-date').val('');
                break;
            }
            $(this).val('');
        break;
        case 'checkbox':
        case 'radio':
        this.checked = false;
    }
  });
}
$('#reset_search_ext').click(function(){reset_search_extf()});
$('#absender').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#betreff').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#empfaenger').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});
$('#volltext').keypress(function(e){if(e.which == 13){document.forms.frm_search_ext.submit();}});


// datePicker localization
$.dpText = {
    TEXT_PREV_YEAR      :   'Letztes Jahr',
    TEXT_PREV_MONTH     :   'Vorheriger Monat',
    TEXT_NEXT_YEAR      :   'Nächstes Jahr',
    TEXT_NEXT_MONTH     :   'Nächster Monat',
    TEXT_CLOSE          :   'Schließen',
    TEXT_CHOOSE_DATE    :   'Datum auswählen',
    HEADER_FORMAT       :   'MMMM JJJJ'
};

// Container Switch
$('#select_container').change(function(){
$.ajax({
    'url': '',
    'data':{ 'CA': 'a_switchContainer',
             'container': $('#select_container').val(),
           },
});
});
